/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.crop.model;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class Crop {

    private Genus genus;
    public static final String PROP_GENUS = "genus";

    
    private Variety variety;
    public static final String PROP_VARIETY = "variety";

    /**
     * Get the value of variety
     *
     * @return the value of variety
     */
    public Variety getVariety() {
        return variety;
    }

    /**
     * Set the value of variety
     *
     * @param variety new value of variety
     */
    public void setVariety(Variety variety) {
        Variety oldVariety = this.variety;
        this.variety = variety;
        propertyChangeSupport.firePropertyChange(PROP_VARIETY, oldVariety, variety);
    }

    /**
     * Get the value of genus
     *
     * @return the value of genus
     */
    public Genus getGenus() {
        return genus;
    }

    /**
     * Set the value of genus
     *
     * @param genus new value of genus
     */
    public void setGenus(Genus genus) {
        Genus oldGenus = this.genus;
        this.genus = genus;
        propertyChangeSupport.firePropertyChange(PROP_GENUS, oldGenus, genus);
    }
    private transient final PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);

    /**
     * Add PropertyChangeListener.
     *
     * @param listener
     */
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        propertyChangeSupport.addPropertyChangeListener(listener);
    }

    /**
     * Remove PropertyChangeListener.
     *
     * @param listener
     */
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        propertyChangeSupport.removePropertyChangeListener(listener);
    }

}
